clear all
% 
% 
%% Importing
% 
% Loading/importing data from the first part of exercise session 2. To
% load, we use the MATLAB function "load".
% 
load('sea_level_practical.mat');
% 
% We have imported the following variable SeaLevel_Station01. The imported
% variable is a matrix with three columns. The first column represents the
% year, the second the month, and the third the mean sea level at the
% mareographic station. The data contains monthly averages for 91 years,
% starting with January 1950.
% 
% we will extract the variables into separate vectors: "yyyy" for the years
% of measurements, "mm" for the months of measurements, and "MSL" for the
% measured mean sea level.

yyyy=SeaLevel_Station01(:,1);
mm=SeaLevel_Station01(:,2);
msl=SeaLevel_Station01(:,3);
% 
%%Reshaping
% 
% We will convert the imported matrix into a more suitable form. We will
% convert the single column vector into a 12x91 matrix using MATLAB reshape
% command. The columns represent the months of the selected year.

MSL=reshape(msl,12,71)';

        %% Question 1. 
        % What happens if we apply the above command to the year
        % ("yyyy") and month ("mm") vector?
                    YYYY=reshape(yyyy,12,71)';
                    MM=reshape(mm,12,71)';
%% Basic statistic
% Calculate the basic statistical parameters for each month. In the
% functions "mean", "std" and "median" second parameter (number) is  dim
% and "returns the mean along dimension dim. For example, if A is a matrix,
% then mean(A,2) is a column vector containing the mean of each row".
MonthMean=mean(MSL,1);
MonthStd=std(MSL,0,1);
MonthMedian=median(MSL,1);

        %% Question 2. 
        % Calculate basic statistical parameters for each year. Hint,
        % set parameter dim=2, to calculate mean of each row.
                    YearMean=mean(MSL,2);
                    YearStd=std(MSL,0,2);
                    YearMedian=median(MSL,2);
            
%% Plots
% 
% Plots MonthMean versus months and draws a vertical error bar at each data
% point.
e1 = errorbar([1:12],MonthMean,MonthStd); hold on
plt1=plot([1:12],MonthMedian);
xlim([0.5, 12.5]);
e1.Color=[0.5 0.5 0.5];
e1.Marker='.'
e1.MarkerSize=5;
e1.MarkerSize=10;
xlabel('Month');
ylabel('Mean sea level [mm]');
legend('Mean','Median', 'Location', 'southeast')

        %% Question 3. 
        % Plot the monthly mean sea level variations through the period
        % 1950 - 2020
        figure
        e2 = errorbar([1:71],YearMean,YearStd); hold on
        plt2=plot([1950:2020],YearMedian);
        xlim([0.5, 71.5]);
        e2.Color=[0.5 0.5 0.5];
        e2.Marker='.'
        e2.MarkerSize=5;
        e2.MarkerSize=10;
        xlabel('Year');
        ylabel('Mean sea level [mm]');
        legend('Mean','Median', 'Location', 'southeast')
        
%% Normal distribution
% Histogram plot of monthly mean seal leves. 

figure; histogram(msl,30,'Normalization','pdf');
hold on
y = 6600:1:7600;
mu = mean(msl);
sigma = std(msl);
f = exp(-(y-mu).^2./(2*sigma^2))./(sigma*sqrt(2*pi));
plot(y,f,'LineWidth',1.5)
xlabel('Mean sea level [mm]');
legend('MSL','Normal distribution');

%% Linear regresion
% https://www.mathworks.com/help/releases/R2017a/matlab/data_analysis/linear-regression.html
x=[1:852]';
X = [ones(length(x),1) x];
b = X\msl;
yCalc2 = X*b;
figure; scatter(x,msl)
hold on
plot(x,yCalc2)
xlabel('Year');
ylabel('Mean sea level [mm]');
ax=gca;
ax.XTick=[6:120:852];
ax.XTickLabel=num2str([1950:10:2020]');

%% Climate regimes
% Detected using code of the STARS algoritam from Rodionv, 2015; https://doi.org/10.3390/cli3030474
[rsi, opts] = stars(msl, 'L', 100, 'p', 0.05, 'h', 1);

[Regime_msl, yy] = starsMeans(msl, rsi);
figure; stairs(Regime_msl, yy, 'm', 'linewidth', 2);
hold on
plot(msl)
ax=gca;
xlabel('Year');
ylabel('Mean sea level [mm]');
ax.XTick=[6:120:852];
ax.XTickLabel=num2str([1950:10:2020]');


        %% Question 4. 
        %Apply different STARS parameter window lengths 'L' to measure
        %the changes in stationarity on different time scales. L=12*30 will try to
        %detect variability of more than 30 years, while L=12*5 will detect much
        %shorter instationarity.

        [rsi, opts] = stars(msl, 'L', 12*30, 'p', 0.05, 'h', 1);

        [Regime_msl, yy] = starsMeans(msl, rsi);
        figure; stairs(Regime_msl, yy, 'm', 'linewidth', 2);
        hold on
        plot(msl)
        xlabel('Year');
        ylabel('Mean sea level [mm]');
        ax=gca;
        ax.XTick=[6:120:852];
        ax.XTickLabel=num2str([1950:10:2020]');
        
        
        [rsi, opts] = stars(msl, 'L', 12*5, 'p', 0.05, 'h', 1);
        [Regime_msl, yy] = starsMeans(msl, rsi);
        figure; stairs(Regime_msl, yy, 'm', 'linewidth', 2);
        hold on
        plot(msl);
        xlabel('Year');
        ylabel('Mean sea level [mm]');
        ax=gca;
        ax.XTick=[6:120:852];
        ax.XTickLabel=num2str([1950:10:2020]');
