%   starsMeans.m
%
%   Calculate the regime-means sequence.  Useful for visualizing the regime
%   means.
%
%   Usage:
%       [xx, yy] = starsMeans(x, rsi);
%
%       xx      - x-values of means sequence
%       yy      - y-values of means sequence
%       x       - original series
%       rsi     - rsi values of x
%
%   Example:
%       > x = rand(100, 1);                 % baseline [0,1] noise
%       > x(18:35) = 3.5;                   % +step transient
%       > x(62:64) = -7.7;                  % brief -step transient
%       > [rsi, opts] = stars(x, 'L', 10, 'p', 0.05, 'h', 1);
%       > plot(x);
%       > hold on;
%       > [xx, yy] = starsMeans(x, rsi);
%       > stairs(xx, yy, 'm', 'linewidth', 2);
%
%   Andrew B. Gardner
%   <andywocky@gmail.com>
%   May 30, 2006

function [xx, yy] = starsMeans(x, rsi);
    % find the change points
	I = find(rsi ~= 0);
	
	% compute the xx, yy vectors for stairs plot of regime means (unweighted)
	xx = unique([1; I(:); length(x)]);
	yy = [];
	for i = 2:length(xx);
		yy(i-1) = mean(x(xx(i-1):xx(i)-1));
	end
	yy(end+1) = mean(x(xx(end):end));
end
